##  Project Cost
Project costs include one-time costs or costs recurring in a limited time frame, for example, costs for change management or to support a transformation initiative. Project costs are maintained on the initiative fact sheet.
**Tip**
Include your internal IT organization as a provider to manage the internally ordered costs.
Cost Type | Field | Description | Where to Find
---|---|---|---
Budget costs Expenses you plan or estimate for the initiative. | CapEx (Budget) | Capital expenditure, one-time expenses related to a project. |  Initiative or project fact sheet > Initiative Setup section > Budget Costs subsection ![Budget costs for Cloud Transformation 2025 showing OpEx and CapEx values.](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio930fec98abaf46e9ae6f2332c3bfbe37_HiRes.png)
OpEx (Budget) | Operational expenditure, recurring project costs in a limited time frame for implementing a new application and running a change project.
Provider costs Services, consultancy or maintenance of a specific service or technology relevant to this project. This is different than IT component costs that will still be relevant after the project.  | CapEx (Ordered) | One-time expenses for a provider. |  Initiative or project fact sheet > Initiative Setup section > Providers subsection ![Provider for Cloud Transformation 2025 showing where to enter OpEx and CapEx information.](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio24d70c826b4f403c88b0c16155461e48_HiRes.png)
OpEx (Ordered) | Recurring expenses for a provider during the time frame of the project.


### Analyze Project Cost
Take a look at your project costs with different reports:
  * Landscape report
  * Matrix report
  * Portfolio report
  * Project Cost report


The project cost report allows you to have all project costs and status for a certain filter (e.g. project category, affected applications) at a single glance.
**Tip**
You can activate the [Project Cost Report](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fstore.leanix.net%2Fen%2Fdetails%2Freport%2F74d1a8b1-3a54-4e89-8557-cdf51fd78a13%2Fff0e6ed0-7618-4489-89ab-9a0bf9cf00ae "https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fstore.leanix.net%2Fen%2Fdetails%2Freport%2F74d1a8b1-3a54-4e89-8557-cdf51fd78a13%2Fff0e6ed0-7618-4489-89ab-9a0bf9cf00ae") from the SAP LeanIX Store. Refer to the [Store](https://help.sap.com/docs/leanix/ea/publishing-custom-reports-on-sap-leanix-store "https://help.sap.com/docs/leanix/ea/publishing-custom-reports-on-sap-leanix-store") documentation for more information.
![Annotated project cost report.](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio577577b4399146e69d8bcfc7ffae007f_LowRes.png)
Image Legend:
1 - Overview of budget and orders for the filtered initiatives
2 - List of all filtered initiatives
3 - Choose the columns you would like to see, you can also add further attributes like NPV or project progress
4 - Relate the numbers to the state of the initiative for your selected year
